==> haskell-test-framework-smallcheck-0.2-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-smallcheck
version: 0.2
id: test-framework-smallcheck-0.2-II2Vw8H8SrH9W3wig0rIF0
key: test-framework-smallcheck-0.2-II2Vw8H8SrH9W3wig0rIF0
license: BSD-3-Clause
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/smallcheck
synopsis: Support for SmallCheck tests in test-framework
description:
    Support for SmallCheck tests in test-framework
category: Testing
abi: 3ad6a7282f2a84c51b547916cbbd752d
exposed: True
exposed-modules:
    Test.Framework.Providers.SmallCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-smallcheck-0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/test-framework-smallcheck-0.2
hs-libraries: HStest-framework-smallcheck-0.2-II2Vw8H8SrH9W3wig0rIF0
depends:
    base-4.12.0.0 smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
    test-framework-0.8.2.0-1YVX6ShIomEAdMYZGh4kn7 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-smallcheck-0.2-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-smallcheck
version: 0.2
id: test-framework-smallcheck-0.2-K1QooTZg0PSuAmQvJE8vq
key: test-framework-smallcheck-0.2-K1QooTZg0PSuAmQvJE8vq
license: BSD-3-Clause
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/smallcheck
synopsis: Support for SmallCheck tests in test-framework
description:
    Support for SmallCheck tests in test-framework
category: Testing
abi: ab7c0483ff54cc42dcb24611a3d8f4fe
exposed: True
exposed-modules:
    Test.Framework.Providers.SmallCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-smallcheck-0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/test-framework-smallcheck-0.2
hs-libraries: HStest-framework-smallcheck-0.2-K1QooTZg0PSuAmQvJE8vq
depends:
    base-4.12.0.0 smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
    test-framework-0.8.2.0-DQsV9kQVQbN9pqcWwfJelK transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
